# randflow
This package is an inflow turbulence generator for large eddy simulation  in wind engineering. The generation methods include [DSRFG](https://doi.org/10.1016/j.jweia.2010.06.002), [CDRFG](https://doi.org/10.1016/j.jweia.2015.04.004) and [NSRFG](https://doi.org/10.1016/j.buildenv.2018.03.059).
